/* $Id: os-linux.h,v 1.8 1999/12/02 01:41:19 chip Exp $
 *
 * Deliver configuration for Linux.
 *
 * $Log: os-linux.h,v $
 * Revision 1.8  1999/12/02 01:41:19  chip
 * Remove HAS_NFS again.
 *
 * Revision 1.7  1999/12/02 01:38:22  chip
 * Don't override MBX_* after all.
 *
 * Revision 1.6  1999/12/02 01:06:49  chip
 * Use <base-posix.h>.
 *
 * Revision 1.5  1999/12/02 00:25:03  chip
 * Set MBX_* macros.
 *
 * Revision 1.4  1999/12/02 00:05:51  chip
 * Add HAS_NFS.
 * Restore ML_DOTLOCK.
 *
 * Revision 1.3  1998/01/11 02:34:18  chip
 * Add HAS_BASENAME.
 *
 * Revision 1.2  1994/10/14 20:08:32  chip
 * Lock only with flock().
 *
 * Revision 1.1  1993/10/28  16:50:11  chip
 * Initial revision
 *
 */

/* Mostly it's POSIX. */

#include <base-posix.h>

/* Then again... */

#undef  SYSV_USRMAIL		/* Mailboxes in /usr/mail, as per SysV	*/

#undef  HAS_UNAME		/* Has uname()		     (SVID)	*/
#define HAS_GETHOSTNAME		/* Has gethostname()	     (BSD)	*/

#undef  LOCK_LOCKF		/* Use lockf(F_LOCK, ...)    (SVID)	*/
#define LOCK_FLOCK		/* Use flock(..., LOCK_EX)   (BSD)	*/

#define HAS_BASENAME		/* Has basename()			*/
#define HAS_USLEEP		/* Has usleep()--microseconds (BSD)	*/
